@@ -142,6 +142,16 @@ class Job():
     def sas_ddg(self, sas: str) -> float:
         return self._sas(sas).ddG
 
+    def sas_glyco_dist(self, sas: str) -> float:
+        if not self._sas(sas).glyco_dist:
+            return None
+        return self._sas(sas).glyco_dist.min_struct_dist
+
+    def sas_glyco_dist_seq(self, sas: str) -> float:
+        if not self._sas(sas).glyco_dist:
+            return None
+        return self._sas(sas).glyco_dist.min_seq_dist
+
     def buried(self, unp_pos: int) -> bool:
         return self._has_residue(self.results.exposure.residues, unp_pos)
 
@@ -202,10 +212,16 @@ class Job():
         return False
 
     def families(self) -> List[Family]:
-        return [fam.id for fam in self.results.conservation.families]
+        fams = self.results.conservation.families
+        if not fams:
+            return []
+        return [fam.id for fam in fams]
 
     def conservation(self, unp_pos: int) -> float:
-        for fam in self.results.conservation.families:
+        fams = self.results.conservation.families
+        if not fams:
+            return 0
+        for fam in fams:
             for res in fam.mappings:
                 if res.position == unp_pos:
                     return res.bitscore
