@@ -77,6 +77,13 @@ class SAS:
     to_aa: str
 
 
+@dataclass_json(letter_case=LetterCase.CAMEL)
+@dataclass
+class GlycoDist:
+    min_seq_dist: int
+    min_struct_dist: float
+
+
 @dataclass_json()
 @dataclass
 class FoldXSAS:
@@ -85,6 +92,7 @@ class FoldXSAS:
     sasa: float
     sasa_apolar: float
     sasa_polar: float
+    glyco_dist: Optional[GlycoDist] = None
 
 
 @dataclass_json()
